@@ -1,5 +1,5 @@
 post.randeff <-
-function(out, classnames=NULL)
+function(out, classnames=NULL, climits=TRUE)
 {
 		nvar <- dim(out$betadraw)[2]
 		nreff <- ncol(out$Deltadraw)
@@ -14,6 +14,9 @@ function(out, classnames=NULL)
 		# class plots  
 		if(is.null(classnames)) return();
 		nshow <- length(classnames)+1
+    ylim <- c(NULL,NULL)
+    if(climits)
+      ylim <- range(out$Deltadraw[-i1])
 		if( nreff <= nvar ) {
 			cat("Unit random effects not available for Z=iota\n")
 		}
@@ -21,7 +24,7 @@ function(out, classnames=NULL)
 			par(ask=T)
 			for(k in 2:nshow) {
 				gi=ng*c(0:(nvar-1))+k
-				matplot(out$Deltadraw[,gi], ty="l", col=cc,
+				matplot(out$Deltadraw[,gi], ty="l", col=cc, ylim=ylim,
 				 main=paste("Random effects for class ",classnames[k-1],sep=""))
 				mtext(paste("Draws for each var of the",nvar,"regression variables"),3)
 				legend("topleft", paste("var",cc), col=cc, lty = c(1, 1, 1), merge = TRUE)
